======================
mob-terragrunt-wrapper
======================


.. image:: https://img.shields.io/pypi/v/tgwrapper.svg
        :target: https://pypi.python.org/pypi/tgwrapper

.. image:: https://img.shields.io/travis/smruti-21/tgwrapper.svg
        :target: https://travis-ci.com/smruti-21/tgwrapper

.. image:: https://readthedocs.org/projects/tgwrapper/badge/?version=latest
        :target: https://tgwrapper.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/smruti-21/tgwrapper/shield.svg
     :target: https://pyup.io/repos/github/smruti-21/tgwrapper/
     :alt: Updates



Terragrunt wrapper for AWS infra deployment


* Free software: MIT license
* Documentation(Not ready yet): https://tgwrapper.readthedocs.io

How to install
--------------

.. code:: bash

    $ pip3 install git+https://github.com/smruti-21/mob-terragrunt-wrapper.git@main

Features
--------

* TODO
